/**
  *  \file planetscentral/mailout/mailout.h
  *  \brief Mailout: Main Program
  */
#ifndef C2SERVER_PLANETSCENTRAL_MAILOUT_MAILOUT_H
#define C2SERVER_PLANETSCENTRAL_MAILOUT_MAILOUT_H

#include <memory>
#include "planetscentral/dbclient/connection.h"
#include "cpluslib/string.h"
#include "planetscentral/mailout/message.h"

class Mutex;
class DbClient;
class DbReadyClient;
class ReconnectingConnection;
class Transmitter;
class IntArgBlock;

extern Mutex output_mutex;
extern DbReadyClient database_connection;
extern ReconnectingConnection database_rc;
extern DbClient hostfile_connection;
extern ReconnectingConnection hostfile_rc;
extern Transmitter transmitter;

/** Connection for command handling. This class stores the state of a
    connection. In particular, this is a message being built using
    multiple commands. */
class MailoutConnection : public Connection {
 public:
    MailoutConnection();
    void handleRequest();
    void handleCommand(const string_t& cmd, IntArgBlock& args);

 private:
    void doMailNew(IntArgBlock& args);
    void doMailParam(IntArgBlock& args);
    void doMailAttach(IntArgBlock& args);
    void doMailSend(IntArgBlock& args);
    void doCancel(IntArgBlock& args);
    void doConfirm(IntArgBlock& args);
    void doRequest(IntArgBlock& args);

    std::auto_ptr<Message> msg;
};

#endif
